<?php

namespace EventPortal\Domain\Event;

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Event\Models\EventDelegate;
use EventPortal\Domain\EventDelegate\RegistrationStatus;
use EventPortal\Enums\InertiaMethod;

class BroadcastCallToAction
{
    /** @var \EventPortal\Contracts\Event */
    private $event;

    /** @var \EventPortal\Domain\Event\Models\EventDelegate */
    private $eventDelegate;

    /** @var bool */
    private $displayWhiteButton = false;

    public static function make(): self
    {
        return new self();
    }

    public function forEventDelegate(EventDelegate $eventDelegate): self
    {
        $this->eventDelegate = $eventDelegate;
        $this->event = $eventDelegate->event;

        return $this;
    }

    public function asWhite(): self
    {
        $this->displayWhiteButton = true;

        return $this;
    }

    public function notWhite(): self
    {
        $this->displayWhiteButton = false;

        return $this;
    }

    /** Get the button */
    public function get(): ?Button
    {
        if ($this->canBeDisplayed() === false) {
            return null;
        }

        $button = Button::make('Access the event')
            ->icon('chevron-right', 'right')
            ->method(InertiaMethod::VISIT())
            ->href($this->event->broadcast_URL);

        if ($button && $this->displayWhiteButton) {
            $button = $button->white();
        }

        return $button;
    }

    public function getAsArray(): array
    {
        return array_filter([$this->get()]);
    }

    /**
     * Broadcast link can be displayed if event is virtual and
     * link is set and event is published and delegate has registered
     */
    public function canBeDisplayed(): bool
    {
        return $this->event->is_virtual &&
            $this->event->broadcast_URL &&
            $this->event->status === 'published' &&
            $this->eventDelegate->statusIs(RegistrationStatus::registered());
    }
}
