<?php

namespace EventPortal\Tests\Feature\Delegate\Event;

use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Form\Models\Form;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Event\Models\EventDelegate;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Http\Response;
use Spatie\Snapshots\MatchesSnapshots;

class EventCancelledTest extends TestCase
{
    use RefreshDatabase, MatchesSnapshots;

    /** @test **/
    public function a_delegate_can_view_the_cancelled_page_for_a_cancelled_event(): void
    {
        $event = factory(Event::class)->states(['cancelled', 'snapshot'])->create();
        $eventDelegate = factory(EventDelegate::class)
            ->state('invited')
            ->create([
                'event_id' => $event->id,
                'delegate_id' => function () {
                    return factory(Delegate::class)
                        ->state('snapshot')
                        ->create()
                        ->id;
                },
            ]);

        factory(Form::class)->state('snapshot')->create(['event_id' => $event->id]);

        $this->assertMatchesJsonSnapshot(
            $this
                ->actingAsDelegate($eventDelegate->delegate)
                ->get(route('event.cancelled', $event->slug))
                ->props()
        );
    }

    /** @test **/
    public function a_delegate_cannot_view_event_if_its_cancelled(): void
    {
        $event = factory(Event::class)->state('cancelled')->create();
        $eventDelegate = factory(EventDelegate::class)->state('invited')->create(['event_id' => $event->id]);
        $form = factory(Form::class)->create();

        $this
            ->actingAsDelegate($eventDelegate->delegate)
            ->get(route('delegate.landing', $event->slug))
            ->assertRedirect(route('event.cancelled', $event->slug));
        $this
            ->actingAsDelegate($eventDelegate->delegate)
            ->get(route('agenda.index', $event->slug))
            ->assertRedirect(route('event.cancelled', $event->slug));
        $this
            ->actingAsDelegate($eventDelegate->delegate)
            ->get(route('venue.index', $event->slug))
            ->assertRedirect(route('event.cancelled', $event->slug));
        $this
            ->actingAsDelegate($eventDelegate->delegate)
            ->get(route('contact.index', $event->slug))
            ->assertRedirect(route('event.cancelled', $event->slug));
        $this
            ->actingAsDelegate($eventDelegate->delegate)
            ->get(route('delegate.form.index', [$event->slug, $form->slug]))
            ->assertRedirect(route('event.cancelled', $event->slug));
    }

    /** @test **/
    public function a_delegate_cannot_view_event_cancelled_page_if_its_not_cancelled(): void
    {
        $event = factory(Event::class)->state('published')->create();
        $eventDelegate = factory(EventDelegate::class)->state('invited')->create(['event_id' => $event->id]);

        $this
            ->actingAsDelegate($eventDelegate->delegate)
            ->get(route('event.cancelled', $event->slug))
            ->assertStatus(Response::HTTP_NOT_FOUND);
    }
}
