<?php

namespace EventPortal\Tests\Unit\Agenda;

use Carbon\Carbon;
use EventPortal\Domain\Agenda\ActiveTabTracker;
use PHPUnit\Framework\TestCase;

class ActiveTabTrackerTest extends TestCase
{
    /** @test **/
    public function current_date_is_active(): void
    {
        $dates = collect([
            Carbon::parse('2021-02-22'),
            Carbon::parse('2021-02-19'),
            Carbon::parse('2021-02-25'),
        ]);

        Carbon::setTestNow('2021-02-22');

        $tracker = new ActiveTabTracker($dates);

        $this->assertTrue($tracker->isActive(Carbon::parse('2021-02-22')));

        $this->assertFalse($tracker->isActive(Carbon::parse('2021-02-19')));
        $this->assertFalse($tracker->isActive(Carbon::parse('2021-02-25')));
    }

    /** @test **/
    public function up_coming_date_is_active(): void
    {
        $dates = collect([
            Carbon::parse('2021-02-19'),
            Carbon::parse('2021-02-22'),
            Carbon::parse('2021-02-25'),
        ]);

        Carbon::setTestNow('2021-02-20');

        $tracker = new ActiveTabTracker($dates);

        $this->assertTrue($tracker->isActive(Carbon::parse('2021-02-22')));

        $this->assertFalse($tracker->isActive(Carbon::parse('2021-02-19')));
        $this->assertFalse($tracker->isActive(Carbon::parse('2021-02-25')));
    }

    /** @test **/
    public function last_date_is_active_if_all_dates_have_passed(): void
    {
        $dates = collect([
            Carbon::parse('2021-02-19'),
            Carbon::parse('2021-02-22'),
            Carbon::parse('2021-02-25'),
        ]);

        Carbon::setTestNow('2021-02-27');

        $tracker = new ActiveTabTracker($dates);

        $this->assertTrue($tracker->isActive(Carbon::parse('2021-02-25')));

        $this->assertFalse($tracker->isActive(Carbon::parse('2021-02-19')));
        $this->assertFalse($tracker->isActive(Carbon::parse('2021-02-22')));
    }
}
