<?php

namespace EventPortal\Tests\Unit\User\Handlers;

use EventPortal\Domain\Form\Payload;
use EventPortal\Domain\User\Handlers\CreateUserIfMissing;
use EventPortal\Domain\User\Models\User;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Pipeline\Pipeline;

class CreateUserIfMissingTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_create_user()
    {
        $payload = Payload::make(['first_name' => 'Jeff'])->withModel(new User);

        app(Pipeline::class)
            ->send($payload)
            ->through([new CreateUserIfMissing])
            ->thenReturn();

        $this->assertDatabaseHas('users', [
            'first_name' => 'Jeff',
        ]);
    }

    /** @test **/
    public function does_nothing_if_user_exists()
    {
        $user = factory(User::class)->create(['first_name' => 'Mike']);

        $payload = Payload::make(['first_name' => 'Jeff'])->withModel($user);

        app(Pipeline::class)
            ->send($payload)
            ->through([new CreateUserIfMissing])
            ->thenReturn();

        $this
            ->assertDatabaseMissing('users', [
                'first_name' => 'Jeff',
            ])
            ->assertDatabaseHas('users', [
                'first_name' => 'Mike',
            ]);
    }
}
